/*
 *      Controls the list view of it-standards
 */
import NavHeader from '@/views/it-standards/Navigationheader'
import Intro from '@/views/it-standards/Intro'
import FilterSidebarLeft from '@/views/it-standards/FilterSidebarLeft'
import { useRouter } from 'next/router'
import { IconArrowBigRight, IconMail, /* IconBooks, */ IconBook2 } from '@tabler/icons-react'

import { handleMailtoEvent, encodeEmail } from '@/lib/utils'

import { remark } from 'remark'
import html from 'remark-html'
import Tooltip from '@/components/Tooltip'
import ServiceTag from '@/components/it-standards/ServiceTag'
import Chip from '@/components/Chip'
import Link from 'next/link'

/* import filterData from '@/lib/assets/data/currentFilter.json' */
import useServiceFilter from 'shared/use-service-filter'
import { ServiceContent } from 'types/ServiceContent'
import { Tag } from 'types/content/'
import useContent from 'shared/use-content'
import useImgPath from 'shared/use-img-path'
export default function ({ contentsString }) {
    const contents: ServiceContent[] = JSON.parse(contentsString)
    const router = useRouter()
    /* const filters = filterData['filter-it-standards'] */
    const { filteredServices /*, activeTagFilters, filterToParams */ } = useServiceFilter(contents, router.query.filter)
    const { getImgPath } = useImgPath()

    /* function handleFilters(event) {
            const filter = event.target.id.split('-')[0]
            if (event.target.checked) {
                activeTagFilters[filter].push(event.target.value)
            } else if (activeTagFilters[filter].indexOf(event.target.value) >= 0) {
                activeTagFilters[filter].splice(activeTagFilters[filter].indexOf(event.target.value), 1)
            }
            // we always track filters in query params, param change will trigger filtering
            router.push(`?filter=${encodeURIComponent(filterToParams())}`, undefined, { shallow: true })
        }
    */

    const hasContentTag = (content: ServiceContent, tagName: string) => {
        const tags: Tag[] = content.tags.filter(tag => tag.name + ':' + tag.value === tagName)
        return tags.length > 0
    }
    return (
        <div className='container it-standards'>
            <div className="">
                <div className="max-w-2xl mx-auto px-3 sm:px-6 lg:px-8 lg:max-w-7xl lg:grid lg:grid-cols-12 lg:gap-8">
                    <div className="col-start-1 col-span-12 ">
                        <NavHeader />
                    </div>
                    <header className="lg:col-start-1 xl:col-start-1 lg:col-span-12 xl:col-span-12 flex flex-row">
                        <Intro />
                    </header>
                    <form name="filters" className="lg:block lg:col-span-2 xl:col-span-2">
                        <FilterSidebarLeft contentsString={contentsString} />
                        { /* <nav
                            aria-label="Sidebar"
                            className="sticky top-4 divide-y divide-gray-300"
                        >
                            {filters.map((filter) => (
                                <div className="pt-6 mt-4" key={filter.id}>
                                    <p
                                        className="text-xs font-semibold text-gray-500 uppercase tracking-wider"
                                        id={`${filter.id}-headline`}
                                    >
                                        {filter.label}
                                    </p>
                                    <div
                                        className="pl-3 mt-3 space-y-2"
                                        aria-labelledby={`${filter.id}-headline`}
                                    >
                                        {filter.options.map((option) => (
                                            <div key={option.value} className="flex items-center hover:cursor-pointer">
                                                <input
                                                    onClick={handleFilters}
                                                    id={`${filter.id}-${option.id}`}
                                                    name={`${filter.id}[]`}
                                                    defaultValue={`${filter.id}:${option.id}`}
                                                    defaultChecked={router.query.filter ? router.query.filter.includes(`${filter.id}:${option.id}`) : false}
                                                    type="checkbox"
                                                    className="h-4 w-4 border-gray-300 rounded text-indigo-600 focus:ring-indigo-500  hover:cursor-pointer"
                                                />
                                                <label
                                                    htmlFor={`${filter.id}-${option.id}`}
                                                    className="ml-3 text-sm text-gray-500  hover:cursor-pointer"
                                                >
                                                    {option.label}
                                                </label>
                                            </div>
                                        ))}
                                    </div>
                                </div>
                            ))}
                                        </nav> */ }
                    </form>
                    <main className="lg:col-start-3 xl:col-start-3 lg:col-span-9 xl:col-span-9">
                        <div className="mt-4">
                            <ul role="list" className="space-y-4">
                                {filteredServices.map((service: ServiceContent, key) => (
                                    // *** A list entry
                                    <li
                                        key={service.name}
                                        className="bg-white px-4 pt-3 pb-6 shadow sm:p-6 sm:rounded-lg"
                                    >
                                        <div className="text-right md:float-right">
                                            {hasContentTag(service, 'label:external')
                                                ? <Tooltip
                                                    delayIn={200}
                                                    delayOut={600}
                                                    content="Bei diesem Inhalt handelt es sich um einen externen Inhalt, der keiner Qualitätssicherung seitens der FITKO unterliegt."
                                                >
                                                    <Chip text={'externer Inhalt'} style={'bg-gray-500'} />
                                                </Tooltip>
                                                : ''}
                                        </div>
                                        <div aria-labelledby={'service-' + key}>
                                            <div className="flex justify-between">
                                                <div className="flex space-x-3">
                                                    {service.logo.path !== '' && service.logo.title !== ''
                                                        ? (
                                                            <div className="flex-shrink-0 xl:py-6">
                                                                <img
                                                                    className="max-w-[100px] h-10"
                                                                    src={getImgPath(service.logo.path)}
                                                                    alt={service.logo.title}
                                                                />
                                                            </div>
                                                        )
                                                        : ''
                                                    }
                                                    <div className="min-w-0 flex-1 xl:py-6">
                                                        <p className="text-xl font-bold text-gray-900">
                                                            <Link href={`/standards/${service.slug}`} passHref legacyBehavior>
                                                                <a className="hover:underline">
                                                                    {service.name}
                                                                </a>
                                                            </Link>
                                                        </p>
                                                    </div>
                                                </div>
                                            </div>
                                            {/* TAGs  */}
                                            <div className="container flex flex-col md:flex-row my-2">
                                                {service.tags.map((tag: Tag, key: number) => {
                                                    return <ServiceTag key={key} tag={tag} style={'bg-gray-400'} />
                                                })}
                                            </div>
                                            {/* Kurzbeschreibung  */}
                                            <div
                                                className="mt-2 text-sm text-gray-700 space-y-4"
                                                dangerouslySetInnerHTML={{
                                                    __html: service.shortDescription !== '' ? remark().use(html).processSync(service.shortDescription) : service.text,
                                                }}
                                            />
                                            <div className="mt-6 flex justify-end space-x-8">
                                                <div className="flex text-sm">
                                                    <span className="inline-flex items-center text-sm mx-5 xl:mx-12">
                                                        <Link href={`${service.docsUrl}`} passHref legacyBehavior>
                                                            <a className="inline-flex space-x-2 text-gray-400 hover:text-gray-800">
                                                                <span className="font-medium">Direkt zur Ressource</span>
                                                                <IconBook2
                                                                    className="h-5 w-5"
                                                                    aria-hidden="true"
                                                                />
                                                            </a>
                                                        </Link>
                                                    </span>
                                                    <span className="inline-flex items-center text-sm">
                                                        <Link href={`/standards/${service.slug}`} passHref legacyBehavior>
                                                            <a className="inline-flex space-x-2 text-gray-400 hover:text-gray-800">
                                                                <span className="font-medium">Mehr</span>
                                                                <IconArrowBigRight
                                                                    className="h-5 w-5"
                                                                    aria-hidden="true"
                                                                />
                                                            </a>
                                                        </Link>
                                                    </span>
                                                </div>
                                            </div>
                                        </div>
                                    </li>
                                ))}
                                <li
                                    key='Additional-Resource'
                                    className="bg-white px-4 py-6 shadow sm:p-6 sm:rounded-lg"
                                >
                                    <div aria-labelledby={'service-add-on'}>
                                        <div className="min-w-0 flex-1">
                                            <p className="text-sm font-medium text-gray-900">
                        Dein zukünftiger Inhalt
                                            </p>
                                        </div>
                                        <div className="mt-2 text-sm text-gray-700 space-y-4">
                      Du kennst weitere Inhalte, die hier nicht gelistet sind? Kontaktiere uns und gebe uns darüber Bescheid. Am einfachsten geht das über unseren Issue-Tracker im Open Source Code Repository der öffentlichen Verwaltung. Schau vor Deinem Feedback bitte in die <a className='text-blue-500' href='https://gitlab.opencode.de/fitko/feedback/-/issues'>Liste der bestehenden Issues</a> und erstelle erst dann <a className='text-blue-500' href='https://gitlab.opencode.de/fitko/feedback/-/issues/new'>ein neues Issue</a>.
                                        </div>
                                        <div className="mt-6 flex justify-end space-x-8" id="kontakt-link">
                                            <div className="flex text-sm">
                                                <span className="inline-flex items-center text-sm">
                                                    <a
                                                        href="#kontakt-link"
                                                        onMouseDown={handleMailtoEvent}
                                                        data-base={`${encodeEmail('fit-connect@fitko.de')}`}
                                                        className="inline-flex space-x-2 text-gray-400 hover:text-gray-800"
                                                    >
                                                        <span className="font-medium">Kontakt</span>
                                                        <IconMail
                                                            className="h-5 w-5"
                                                            aria-hidden="true"
                                                        />
                                                    </a>
                                                </span>
                                            </div>
                                        </div>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </main>
                </div>
            </div>
        </div>
    )
}

export async function getStaticProps() {
    const { contents } = useContent('standards')

    return {
        props: {
            contentsString: JSON.stringify(contents),
        },
    }
}
